@@ -13,9 +13,13 @@ typedef Eo Eio_Model;
 
 
 #endif
+/** Eio model class
+ *
+ * @ingroup Eio_Model
+ */
 #define EIO_MODEL_CLASS eio_model_class_get()
 
-EAPI const Eo_Class *eio_model_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *eio_model_class_get(void);
 
 /**
  * @brief Set children filter callback.
@@ -27,13 +31,14 @@ EAPI const Eo_Class *eio_model_class_get(void) EINA_CONST;
  *
  * See also @ref efl_model_children_slice_get.
  *
+ * @param[in] filter_cb Filter callback
  * @param[in] userdata User's private data
  *
  * @since 1.11
  *
  * @ingroup Eio_Model
  */
-EOAPI void  eio_model_children_filter_set(Eio_Filter_Direct_Cb filter_cb, void *userdata);
+EOAPI void eio_model_children_filter_set(Eo *obj, Eio_Filter_Direct_Cb filter_cb, void *userdata);
 
 /**
  * @brief Custom Eio_Model constructor.
@@ -44,7 +49,7 @@ EOAPI void  eio_model_children_filter_set(Eio_Filter_Direct_Cb filter_cb, void *
  *
  * @ingroup Eio_Model
  */
-EOAPI void  eio_model_path_set(const char *path);
+EOAPI void eio_model_path_set(Eo *obj, const char *path);
 
 
 #endif
