@@ -227,7 +227,7 @@ EAPI Eina_List *evas_object_table_children_get(const Evas_Table *obj) EINA_WARN_
  *
  * @ingroup Evas_Table
  */
-EAPI Evas_Object *evas_object_table_child_get(const Evas_Table *obj, unsigned short col, unsigned short row);
+EAPI Efl_Canvas_Object *evas_object_table_child_get(const Evas_Table *obj, unsigned short col, unsigned short row);
 
 /**
  * @brief Faster way to remove all child objects from a table object.
@@ -261,11 +261,12 @@ EAPI Eina_Iterator *evas_object_table_iterator_new(const Evas_Table *obj) EINA_W
  *
  * @ingroup Evas_Table
  */
-EAPI Evas_Object *evas_object_table_add_to(Evas_Table *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_table_add_to(Evas_Table *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Get packing location of a child of table
  *
+ * @param[in] child The child object to add.
  * @param[out] col pointer to store relative-horizontal position to place
  * child.
  * @param[out] row pointer to store relative-vertical position to place child.
@@ -280,7 +281,7 @@ EAPI Evas_Object *evas_object_table_add_to(Evas_Table *obj) EINA_WARN_UNUSED_RES
  *
  * @ingroup Evas_Table
  */
-EAPI Eina_Bool evas_object_table_pack_get(const Evas_Table *obj, Evas_Object *child, unsigned short *col, unsigned short *row, unsigned short *colspan, unsigned short *rowspan);
+EAPI Eina_Bool evas_object_table_pack_get(const Evas_Table *obj, Efl_Canvas_Object *child, unsigned short *col, unsigned short *row, unsigned short *colspan, unsigned short *rowspan);
 
 /**
  * @brief Add a new child to a table object or set its current packing.
@@ -291,6 +292,7 @@ EAPI Eina_Bool evas_object_table_pack_get(const Evas_Table *obj, Evas_Object *ch
  * storage, and attempting to use values not able to fit in 16bits will result
  * in failure.
  *
+ * @param[in] child The child object to add.
  * @param[in] col relative-horizontal position to place child.
  * @param[in] row relative-vertical position to place child.
  * @param[in] colspan how many relative-horizontal position to use for this
@@ -302,7 +304,7 @@ EAPI Eina_Bool evas_object_table_pack_get(const Evas_Table *obj, Evas_Object *ch
  *
  * @ingroup Evas_Table
  */
-EAPI Eina_Bool evas_object_table_pack(Evas_Table *obj, Evas_Object *child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan) EINA_ARG_NONNULL(2);
+EAPI Eina_Bool evas_object_table_pack(Evas_Table *obj, Efl_Canvas_Object *child, unsigned short col, unsigned short row, unsigned short colspan, unsigned short rowspan) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Remove child from table.
@@ -317,6 +319,6 @@ EAPI Eina_Bool evas_object_table_pack(Evas_Table *obj, Evas_Object *child, unsig
  *
  * @ingroup Evas_Table
  */
-EAPI Eina_Bool evas_object_table_unpack(Evas_Table *obj, Evas_Object *child) EINA_ARG_NONNULL(2);
+EAPI Eina_Bool evas_object_table_unpack(Evas_Table *obj, Efl_Canvas_Object *child) EINA_ARG_NONNULL(2);
 
 #endif
